# Modeling: Objectives and Transformation Items (Projects) (Meta Model v3)
### On this page
  * [Objectives](https://help.sap.com/docs/leanix/ea/objectives-and-transformations-items-v3#objectives)
  * [Projects](https://help.sap.com/docs/leanix/ea/objectives-and-transformations-items-v3#projects)
  * [Business Transformation Management (BTM) Logic](https://help.sap.com/docs/leanix/ea/objectives-and-transformations-items-v3#business-transformation-management-\(btm\)-logic)
  * [Example: Cloud migration with BTM](https://help.sap.com/docs/leanix/ea/objectives-and-transformations-items-v3#example:-cloud-migration-with-btm)


Objective Fact Sheets allow for high-level definition and progress tracking of transformation initiatives and can be linked to Business Capabilities. Define Objectives to improve the business:
  * Allows high-level progress tracking
  * Identifies critical business capabilities
  * Enables org. wide transparency


Transformation Item or Projects Fact Sheets, on the other hand, are used to plot detailed actions for achieving an Objective and as a way to model changes upon every other Fact Sheet in the wider LeanIX Meta Model. Create detailed plans to achieve Objectives:
  * Define a high-level transformation for those plans and project changes
  * Out-of-the-box Transformation Items consist of three hierarchies: Plan, Building Block, Epic and Project


![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27439cc57a441014a241b0be52fe7304_LowRes.png)
